itf2img
====
A downlink image data creation/analysis tool for the ultra small satellite ITF-2 of the YUI project, the University of Tsukuba.

Features
======
 * Convert a text file into a PNG image
 * Convert a PNG image into a text file
 * An [original image format](ITF-2_image_format.pdf) is used for saving the data size

Usage
======

Decoding received data (In the hexadecimal format)
----
When decoding a F2D packet from ITF-2 with decoding software such as [direwolf](https://github.com/wb2osz/direwolf), the data is displayed in hexadecimal format shown as following way.<br>

494D30523907070410FF54545454FFFFFF5454FFFFFF54FF9F6F3F3F6F9F6F3F9F6F9F3F9F6F9F3F9F6FFFA400C0C0C0FFFF00FF00FFFFFFFFE023456789ABCDF1F1F11F1F1F11FFF1FFF11F1F1F11F1FFF0<br>

This is an example of a image data written in the [original image format](ITF-2_image_format.pdf).<br>
The initial 3 Bytes are `494D30` which is `IM0` in the ascii characters.

Save the whole text into a text file with a name `hex.txt`.<br>
The text file name is `hex.txt` in this guide, but other names also work.<br>

To convert the text file into an PNG image, type the following command.<br>

```
./itf2img h2p -o img.png hex.txt
```

`h2p` is an embedded command of itf2img that loads a hexadecimal formatted text file and exports a PNG image.<br>
The option `-o` designates the output file path. If the `-o` option is omitted, the default output file name `a.png` is automatically applied.

The exported image `img.png` is same as the following PNG image.<br>
<img src="./sample/img0_4bit.png"><br>

Decoding received data (In the decimal format)
----
A text file `dec.txt` has a following content.<br>

73 77 48 82 57 7 7 4 16 255 84 84 84 84 255 255 255 84 84 255 255 255 84 255 159 111 63 63 111 159 111 63 159 111 159 63 159 111 159 63 159 111 255 164 0 192 192 192 255 255 0 255 0 255 255 255 255 224 35 69 103 137 171 205 241 241 241 31 31 31 17 255 241 255 241 31 31 31 17 241 255 240 <br>

The initial 3 words are `73 77 48` which is `IM0` in the ascii characters.<br>
Different from hexadecimal formatted text, each data must be separated with a single space.<br>

To convert the text file into an image, type the following command.<br>

```
./itf2img d2p -o img.png dec.txt
```

`d2p` is an embedded command of itf2img that loads a decimal formatted text file and exports a PNG image.<br>
The option `-o` designates the output file path in the same way of `d2p` command.<br>

The exported image `img.png` is same as the following image.<br>
<img src="./sample/img0_4bit.png"><br>

Converting a PNG image into a ITF-2 command file
----
This item is written for operation team members of the YUI project, University of Tsukuba.<br>

The image downlink is executed with the data format "Communication system A long message 0" which format number is 40.<br>
This format is only available on F2D downlink.<br>
Because of the specification of the satellite, the data size in single packet of F2D is limited up to 171 Bytes.<br>
The data size that can be used for the image downlink is 85 Bytes, the half of the maximum limit of F2D packet data size.<br>

Thus, to uplink an image, we have to convert the original PNG image into a down sized image format.<br>
The detailed information on the down sized image format is available on [ITF-2\_image\_format.pdf](-2_image_format.pdf) in the same folder.<br>

To convert an [sample/img0\_4bit.png](sample/img0_4bit.png) into an uplink command file, type the following command.<br>

```
./itf2img d2c -o cmd.txt img.png
```

`p2c` is an embedded command of itf2img that loads a PNG image into an ITF-2 uplink command file.<br>
The option `-o` designates the output file path in the same way of `d2p` command.<br>
If the down sized image data exceeds 85 Bytes, the conversion fails, be careful.<br>
When the conversion succeeds, a text file with the following content is acquired.<br>

"CMDS","17","12","19","12","51","25","DLD","164","52","57","52","61","51","48","53","50","51","57","48","55","48","55","48","52","49","48","63","63","53","52","53","52","53","52","53","52","63","63","63","63","63","63","53","52","53","52","63","63","63","63","63","63","53","52","63","63","57","63","54","63","51","63","51","63","54","63","57","63","54","63","51","63","57","63","54","63","57","63","51","63","57","63","54","63","57","63","51","63","57","63","54","63","63","63","58","52","48","48","60","48","60","48","60","48","63","63","63","63","48","48","63","63","48","48","63","63","63","63","63","63","63","63","62","48","50","51","52","53","54","55","56","57","58","59","60","61","63","49","63","49","63","49","49","63","49","63","49","63","49","49","63","63","63","49","63","63","63","49","49","63","49","63","49","63","49","49","63","49","63","63","63","48",<br>

This uplink command file can be used by copying into the directory for uplink commands used by the direwolf client software (TX system). Don't forget to edit 'CMD.INI' to register the new uplink command file.<br>

Embedded commands, command line options
====

Syntax<br>
----

```
./itf2img [--version] [--help] [-verbose] <command> [<args>] <path>
```

Command line options `[???]`
----
 * `--version` Shows the version then terminates.
 * `--help` Shows the help then terminates.
 * `-verbose` `-v` Enables detailed information display.

Embedded commands `<command>`
----
 * `s` Shows downsized image data size in Bytes.
 * `i` Shows image data size before/after downsizing in Bytes.
 * `h2p` Converts a hexadecimal formatted text file into a PNG image.
 * `d2p` Converts a decimal formatted text file into a PNG image.
 * `p2h` Converts a PNG image file into a hexadecimal formatted text file.
 * `p2d` Converts a PNG image file into a decimal formatted text file.
 * `p2c` Converts a PNG image file into a ITF-2 uplink command file.

Options for embedded commands `[<args>]`
----
 * `-o <path>` Designates the output file path (effective on `h2p`, `d2p`, `p2h`, `p2d`, `p2c` command.)

Input file `<path>`
----
Designates the input file path.<br>

Install
======
Unzip the zip file.<br>
When uninstall, delete the folder.<br>

Dependencies
======
 * [zlib 1.2.X](http://www.zlib.net/)
 * [libpng 1.6.X](http://www.libpng.org/pub/png/libpng.html)
 * [Windows SDK](https://developer.microsoft.com/ja-jp/windows/downloads/windows-8-1-sdk) (Only on windows)

Build
======
UNIX<br>
----
Execute the following command after installing zlib and libpng.<br>

```
make -f makefile_unix.mk && install itf2img.out /usr/local/bin
```

Windows<br>
----
You have to install a terminal software such as Cygwin or MSYS2.<br>
Set path to SDKs beforehand.<br>
Overwrite compiler/linker path in [makefile\_win32.mk](./makefile_win32.mk) for your build environment.<br>

```
nmake /f makefile_win32.mk DEBUG=0
```

Licenses
======
itf2img is released under the MIT license.<br>
[http://opensource.org/licenses/mit-license.php](http://opensource.org/licenses/mit-license.php)
