﻿#!/bin/bash
# Author Mamoru Kaminaga
# Date 2017/12/17
# Shell script for release. On windows, run this script on cygwin or MSYS2.
# Copyright 2017 Mamoru Kaminaga
# Released under the MIT license
# http://opensource.org/licenses/mit-license.php
if [[ "$1" = "" ]]; then
  echo 'need args, 1->unix, 2->win32'
  exit 1
fi

# Required: The latest version.
VERSION=$(git describe --tags)

# Output directory is created
OUTDIR="release"
mkdir -p ${OUTDIR}

rm *.out
rm *.exe

if [[ "$1" = "1" ]]; then
  # Build test for UNIX.
  touch *.cc
  make -f makefile_unix.mk
  if [[ $? != 0 ]]; then
    echo 'Build error'
    exit 1
  fi

  ./test.sh 1
  if [[ $? != 0 ]]; then
    echo 'Test failed'
    exit 1
  else
    echo 'Test passed!'
  fi

  # Output sub directory is created
  TARGET_BINDIR="itf2img_${VERSION}_unix"
elif [[ "$1" = "2" ]]; then
  # Build test for Windows (Console).
  touch *.cc
  nmake /f makefile_win32.mk DEBUG=0 | iconv -f cp932 -t utf-8
  if [[ $? != 0 ]]; then
    echo 'Build error'
    exit 1
  fi

  ./test.sh 2
  if [[ $? != 0 ]]; then
    echo 'Test failed'
    exit 1
  else
    echo 'Test passed!'
  fi

  # Output sub directory is created
  TARGET_BINDIR="itf2img_${VERSION}_win32"
fi

cd ${OUTDIR}
if [[ -e ${TARGET_BINDIR} ]]; then rm -r ${TARGET_BINDIR}; fi
mkdir -p ${TARGET_BINDIR}

# The bin is packed.
mkdir ${TARGET_BINDIR}/sample
cp ../sample/*.png ${TARGET_BINDIR}/sample  # sample PNG images used in the test
cp ../*.md ${TARGET_BINDIR}  # Descriptions
cp ../*.pdf ${TARGET_BINDIR}  # Descriptions
if [[ "$1" = "1" ]]; then
  cp ../*.out ${TARGET_BINDIR}  # Executable files for Windows
elif [[ "$1" = "2" ]]; then
  cp ../*.exe ${TARGET_BINDIR}  # Executable files for UNIX
fi
zip -r ${TARGET_BINDIR}.zip ${TARGET_BINDIR}

# The src is packed.
TARGET_SRCDIR="itf2img_${VERSION}"
if [[ -e ${TARGET_SRCDIR} ]]; then rm -r ${TARGET_SRCDIR}; fi
mkdir -p ${TARGET_SRCDIR}
mkdir ${TARGET_SRCDIR}/sample
cp ../sample/*.png ${TARGET_SRCDIR}/sample  # sample PNG images used in the test
cp ../*.md ${TARGET_SRCDIR}  # Descriptions
cp ../*.pdf ${TARGET_SRCDIR}  # Descriptions
cp ../*.cc ${TARGET_SRCDIR}  # Source code
cp ../*.h ${TARGET_SRCDIR}  # Header file
cp ../*.sh ${TARGET_SRCDIR}  # Shell scripts.
cp ../*.mk ${TARGET_SRCDIR}  # Makefile.
zip -r ${TARGET_SRCDIR}.zip ${TARGET_SRCDIR}
