#!/bin/bash
# Test script for itf2img.
# test_win32.sh
# Copyright 2017 Mamoru Kaminaga
# Released under the MIT license
# http://opensource.org/licenses/mit-license.php
TESTDIR='./test'
TMPFILE=$(mktemp)
trap "rm -r ${TMPFILE}" 0 1 2 3 15

if [[ "$1" = "" ]]; then
  echo 'need args, 1->unix, 2->win32'
  exit 1
fi

function test() {
  local itf2img=''
  if [[ ${1} -eq 1 ]]; then
    itf2img='./itf2img.out'
  else
    itf2img='./itf2img.exe'
  fi

  mkdir -p ${TESTDIR}
  rm ${TESTDIR}/*

  echo 'Test start'
  echo '===='

  # Test on 4bit image
  for i in 1 2 4; do

    echo "${i}bit"
    echo "========"

    echo 'PNG -> Decimal'
    ${itf2img} p2d -o ${TESTDIR}/${i}bit_p2d.txt sample/img0_${i}bit.png
    if [[ $? -eq 0 ]]; then
      echo 'succeed'
    else
      echo 'failure'
      exit 1
    fi
    echo ""

    echo 'PNG -> Hexadecimal'
    ${itf2img} p2h -o ${TESTDIR}/${i}bit_p2h.txt sample/img0_${i}bit.png
    if [[ $? -eq 0 ]]; then
      echo 'succeed'
    else
      echo 'failure'
      exit 1
    fi
    echo ""

    echo 'PNG -> Command'
    ${itf2img} p2c -o ${TESTDIR}/${i}bit_p2c.txt sample/img0_${i}bit.png
    if [[ $? -eq 0 ]]; then
      echo 'succeed'
    else
      echo 'failure'
      exit 1
    fi
    echo ""

    echo 'Decimal -> PNG'
    ${itf2img} d2p -o ${TESTDIR}/${i}bit_d2p.png ${TESTDIR}/${i}bit_p2d.txt
    if [[ $? -eq 0 ]]; then
      echo 'succeed'
    else
      echo 'failure'
      exit 1
    fi
    echo ""

    echo 'Hexadecimal -> PNG'
    ${itf2img} h2p -o ${TESTDIR}/${i}bit_h2p.png ${TESTDIR}/${i}bit_p2h.txt
    if [[ $? -eq 0 ]]; then
      echo 'succeed'
    else
      echo 'failure'
      exit 1
    fi
    echo ""

    echo 'Command -> Decimal -> PNG'
    sed -e 's/"//g' \
      -e 's/,/\ /g' \
      -e 's/CMDS[^D]*DLD\ [^ ]*\ //g' \
      -e 's/\([^ ]*\)*\ \([^ ]*\)\ */\1\ \2\n/g' \
      ${TESTDIR}/${i}bit_p2c.txt > ${TMPFILE}
    : > ${TESTDIR}/${i}bit_c2d.txt
    while read -a line; do
      # Extract a line
      local a=${line[0]}
      local b=${line[1]}
      # Ascii to dec
      local ai=0
      local bi=0
      if [[ ${a} -ge 65 ]]; then
        ai=$((${a} - 65))
      else
        ai=$((${a} - 48))
      fi
      if [[ ${b} -ge 65 ]]; then
        bi=$((${b} - 65))
      else
        bi=$((${b} - 48))
      fi
      local d=$((${ai} * 16 + ${bi}))
      echo "${d}" >> ${TESTDIR}/${i}bit_c2d.txt
    done < ${TMPFILE}

    ${itf2img} d2p -o ${TESTDIR}/${i}bit_c2p.png ${TESTDIR}/${i}bit_c2d.txt
    if [[ $? -eq 0 ]]; then
      echo 'succeed'
    else
      echo 'failure'
      exit 1
    fi
    echo ""

  done

  echo 'Test succeeded'
}

test ${1}
